@@ -7,11 +7,23 @@ available_samplings_covariates <- c("dyad", "covar-dyad", "node", "covar-node")
 
 l1_similarity <- function(x, y) {-abs(x - y)}
 
+clustering_indicator <- function(clustering) {
+  K <- max(unique(clustering))
+  N  <- length(clustering)
+  Z <- matrix(0, N, K)
+  Z[cbind(seq.int(N), clustering)] <- 1
+  Z
+}
+
 bar <- function(X) {
   X.bar <- 1 - X ; diag(X.bar) <- 0
   X.bar
 }
 
+quad_form <- function(A,x) {t(x) %*% A %*% x}
+
+t_quad_form <- function(A,x) {x %*% A %*% t(x)}
+
 array2list <-function(X) {
   if (is.null(X)) {
     L <- list()
@@ -24,7 +36,7 @@ array2list <-function(X) {
 }
 
 format_covariates <- function(covariates, similarity) {
-  if (!is.null(covariates)) {
+  if (length(covariates) > 0) {
     # Conversion of covariates to an array
     covariates <- simplify2array(covariates)
     # if a list of vector (covariates node-centered), will be a matrix
@@ -59,10 +71,23 @@ getCovarArray <- function(X, s) {
   phi
 }
 
-quad_form <- function(A,x) {t(x) %*% A %*% x}
+#'
+#' @importFrom Matrix drop0
+dropNA <- function(x) {
+    if(!is(x, "matrix")) stop("x needs to be a matrix!")
+
+    zeros <- which(x==0, arr.ind=TRUE)
+    ## keep zeros
+    x[is.na(x)] <- 0
+    x[zeros] <- NA
+    x <- drop0(x)
+    x[zeros] <- 0
+    x
+}
 
 .logistic <- function(x) {1/(1 + exp(-x))}
 .logit    <- function(x) {log(x/(1 - x))}
+.xlogx    <- function(x) ifelse(x < .Machine$double.eps, 0, x*log(x))
 
 .softmax <- function(x) {
   b <- max(x)
