@@ -1,31 +1,20 @@
 context("test network samplers (Class networkSampler and chidren)")
 
-source("utils_test.R")
-
-set.seed(178303)
-### A SBM model : ###
 N <- 200
-Q <- 3
-pi <- rep(1, Q)/Q            # block proportion
-theta <- list(mean = diag(.45, Q, Q) + .05)  # connectivity matrix
+N_nocov <- N
+N_cov   <- N
+M <- 10
+source("utils_test.R", local = TRUE)
+### Draw a SBM model (Bernoulli, undirected)
+sampler_undirected_nocov$rNetwork(store = TRUE)
 directed <- FALSE
 
-### Draw a SBM model (Bernoulli, undirected)
-mySBM <- sbm::sampleSimpleSBM(N, pi, theta)
-A <- mySBM$netMatrix
-
 ### Draw a SBM model (Bernoulli, undirected) with covariates
-M <- 10
-covariates_node <- replicate(M, rnorm(N,mean = 0, sd = 1), simplify = FALSE)
-covarMatrix <- simplify2array(covariates_node)
+covarMatrix <- simplify2array(covarList_node)
 covarArray  <- missSBM:::getCovarArray(covarMatrix, missSBM:::l1_similarity)
-covariates_dyad <- lapply(seq(dim(covarArray)[3]), function(x) covarArray[ , , x])
-covarParam  <- rnorm(M, 0, 1)
-sbm <- sbm::sampleSimpleSBM(N, pi, theta, covariates = covariates_dyad, covariatesParam = covarParam)
-A_cov <- sbm$netMatrix
 
 ## tolerance for tests
-tol <- 1e-2
+tol <- 2e-1
 
 test_that("Consistency of dyad-centered sampler", {
 
@@ -62,7 +51,6 @@ test_that("Consistency of simple node-centered sampling", {
   expect_equal(mySampler$type, "node")
   expect_equal(mySampler$df, 1)
   expect_equal(mySampler$parameters, psi)
-  expect_equal(length(mySampler$prob), N)
   mySampler$rSamplingMatrix()
   expect_equal(dim(mySampler$samplingMatrix), c(N,N))
   samplingRate <- sum(mySampler$samplingMatrix)/N^2
@@ -75,7 +63,6 @@ test_that("Consistency of simple node-centered sampling", {
   expect_equal(mySampler$type, "node")
   expect_equal(mySampler$df, M)
   expect_equal(mySampler$parameters, psi)
-  expect_equal(length(mySampler$prob), N)
   mySampler$rSamplingMatrix()
   expect_equal(dim(mySampler$samplingMatrix), c(N,N))
 })
@@ -83,7 +70,7 @@ test_that("Consistency of simple node-centered sampling", {
 test_that("Consistency of double-standard sampling", {
 
   psi <- c(0.1, 0.5)
-  mySampler <- missSBM:::doubleStandardSampler$new(psi, A, directed)
+  mySampler <- missSBM:::doubleStandardSampler$new(psi, sampler_undirected_nocov$networkData, directed)
   expect_is(mySampler, "doubleStandardSampler")
   expect_equal(mySampler$type, "double-standard")
   expect_equal(mySampler$df, 2)
@@ -95,10 +82,10 @@ test_that("Consistency of double-standard sampling", {
 test_that("Consistency of block-node sampling", {
 
   psi <- c(.1, .2, .7)
-  mySampler <- missSBM:::blockNodeSampler$new(psi, N, directed, mySBM$memberships)
+  mySampler <- missSBM:::blockNodeSampler$new(psi, N, directed, sampler_undirected_nocov$memberships)
   expect_is(mySampler, "blockNodeSampler")
   expect_equal(mySampler$type, "block-node")
-  expect_equal(mySampler$df, mySBM$nbBlocks)
+  expect_equal(mySampler$df, sampler_undirected_nocov$nbBlocks)
   expect_equal(mySampler$parameters, psi)
   mySampler$rSamplingMatrix()
   expect_equal(dim(mySampler$samplingMatrix), c(N,N))
@@ -109,7 +96,7 @@ test_that("Consistency of block-node sampling", {
 test_that("Consistency of degree network sampling", {
 
   psi <- c(.01, .01)
-  mySampler <- missSBM:::degreeSampler$new(psi, rowSums(A), directed)
+  mySampler <- missSBM:::degreeSampler$new(psi, rowSums(sampler_undirected_nocov$networkData), directed)
   expect_is(mySampler, "degreeSampler")
   expect_equal(mySampler$type, "degree")
   expect_equal(mySampler$df, 2)
@@ -122,7 +109,7 @@ test_that("Consistency of degree network sampling", {
 test_that("Consistency of block-dyad sampling", {
 
   psi <- diag(.45, Q, Q) + .05
-  mySampler <- missSBM:::blockDyadSampler$new(psi, N, directed, mySBM$memberships)
+  mySampler <- missSBM:::blockDyadSampler$new(psi, N, directed, sampler_undirected_nocov$memberships)
   expect_is(mySampler, "blockDyadSampler")
   expect_equal(mySampler$type, "block-dyad")
   expect_equal(mySampler$df, Q * (Q + 1) / 2)
@@ -136,7 +123,7 @@ test_that("Consistency of block-dyad sampling", {
 test_that("Consistency of snowball sampling", {
 
   param <- c(2,.05)
-  mySampler <- missSBM:::snowballSampler$new(param, A, directed)
+  mySampler <- missSBM:::snowballSampler$new(param, sampler_undirected_nocov$networkData, directed)
   expect_is(mySampler, "snowballSampler")
   expect_equal(mySampler$type, "snowball")
   expect_equal(mySampler$parameters, param)
